@@ -13,7 +13,6 @@ enum {
 	F_MARK = 1 << 0,
 };
 
-/* Function which prints out usage message. */
 static void MARK_help(void)
 {
 	printf(
@@ -59,22 +58,23 @@ MARK_parse_v0(int c, char **argv, int invert, unsigned int *flags,
 {
 	struct xt_mark_target_info *markinfo
 		= (struct xt_mark_target_info *)(*target)->data;
+	unsigned int mark = 0;
 
 	switch (c) {
 	case '1':
-		if (string_to_number_l(optarg, 0, 0, 
-				     &markinfo->mark))
-			exit_error(PARAMETER_PROBLEM, "Bad MARK value `%s'", optarg);
+		if (!xtables_strtoui(optarg, NULL, &mark, 0, UINT32_MAX))
+			xtables_error(PARAMETER_PROBLEM, "Bad MARK value \"%s\"", optarg);
+		markinfo->mark = mark;
 		if (*flags)
-			exit_error(PARAMETER_PROBLEM,
+			xtables_error(PARAMETER_PROBLEM,
 			           "MARK target: Can't specify --set-mark twice");
 		*flags = 1;
 		break;
 	case '2':
-		exit_error(PARAMETER_PROBLEM,
+		xtables_error(PARAMETER_PROBLEM,
 			   "MARK target: kernel too old for --and-mark");
 	case '3':
-		exit_error(PARAMETER_PROBLEM,
+		xtables_error(PARAMETER_PROBLEM,
 			   "MARK target: kernel too old for --or-mark");
 	default:
 		return 0;
@@ -86,19 +86,18 @@ MARK_parse_v0(int c, char **argv, int invert, unsigned int *flags,
 static void MARK_check(unsigned int flags)
 {
 	if (!flags)
-		exit_error(PARAMETER_PROBLEM,
+		xtables_error(PARAMETER_PROBLEM,
 		           "MARK target: Parameter --set/and/or-mark"
 			   " is required");
 }
 
-/* Function which parses command options; returns true if it
-   ate an option */
 static int
 MARK_parse_v1(int c, char **argv, int invert, unsigned int *flags,
               const void *entry, struct xt_entry_target **target)
 {
 	struct xt_mark_target_info_v1 *markinfo
 		= (struct xt_mark_target_info_v1 *)(*target)->data;
+	unsigned int mark = 0;
 
 	switch (c) {
 	case '1':
@@ -114,11 +113,11 @@ MARK_parse_v1(int c, char **argv, int invert, unsigned int *flags,
 		return 0;
 	}
 
-	if (string_to_number_l(optarg, 0, 0, &markinfo->mark))
-		exit_error(PARAMETER_PROBLEM, "Bad MARK value `%s'", optarg);
-
+	if (!xtables_strtoui(optarg, NULL, &mark, 0, UINT32_MAX))
+		xtables_error(PARAMETER_PROBLEM, "Bad MARK value \"%s\"", optarg);
+	markinfo->mark = mark;
 	if (*flags)
-		exit_error(PARAMETER_PROBLEM,
+		xtables_error(PARAMETER_PROBLEM,
 			   "MARK target: Can't specify --set-mark twice");
 
 	*flags = 1;
@@ -129,21 +128,21 @@ static int mark_tg_parse(int c, char **argv, int invert, unsigned int *flags,
                          const void *entry, struct xt_entry_target **target)
 {
 	struct xt_mark_tginfo2 *info = (void *)(*target)->data;
-	unsigned int value, mask = ~0U;
+	unsigned int value, mask = UINT32_MAX;
 	char *end;
 
 	switch (c) {
 	case 'X': /* --set-xmark */
 	case '=': /* --set-mark */
-		param_act(P_ONE_ACTION, "MARK", *flags & F_MARK);
-		param_act(P_NO_INVERT, "MARK", "--set-xmark/--set-mark", invert);
-		if (!strtonum(optarg, &end, &value, 0, ~0U))
-			param_act(P_BAD_VALUE, "MARK", "--set-xmark/--set-mark", optarg);
+		xtables_param_act(XTF_ONE_ACTION, "MARK", *flags & F_MARK);
+		xtables_param_act(XTF_NO_INVERT, "MARK", "--set-xmark/--set-mark", invert);
+		if (!xtables_strtoui(optarg, &end, &value, 0, UINT32_MAX))
+			xtables_param_act(XTF_BAD_VALUE, "MARK", "--set-xmark/--set-mark", optarg);
 		if (*end == '/')
-			if (!strtonum(end + 1, &end, &mask, 0, ~0U))
-				param_act(P_BAD_VALUE, "MARK", "--set-xmark/--set-mark", optarg);
+			if (!xtables_strtoui(end + 1, &end, &mask, 0, UINT32_MAX))
+				xtables_param_act(XTF_BAD_VALUE, "MARK", "--set-xmark/--set-mark", optarg);
 		if (*end != '\0')
-			param_act(P_BAD_VALUE, "MARK", "--set-xmark/--set-mark", optarg);
+			xtables_param_act(XTF_BAD_VALUE, "MARK", "--set-xmark/--set-mark", optarg);
 		info->mark = value;
 		info->mask = mask;
 
@@ -152,28 +151,28 @@ static int mark_tg_parse(int c, char **argv, int invert, unsigned int *flags,
 		break;
 
 	case '&': /* --and-mark */
-		param_act(P_ONE_ACTION, "MARK", *flags & F_MARK);
-		param_act(P_NO_INVERT, "MARK", "--and-mark", invert);
-		if (!strtonum(optarg, NULL, &mask, 0, ~0U))
-			param_act(P_BAD_VALUE, "MARK", "--and-mark", optarg);
+		xtables_param_act(XTF_ONE_ACTION, "MARK", *flags & F_MARK);
+		xtables_param_act(XTF_NO_INVERT, "MARK", "--and-mark", invert);
+		if (!xtables_strtoui(optarg, NULL, &mask, 0, UINT32_MAX))
+			xtables_param_act(XTF_BAD_VALUE, "MARK", "--and-mark", optarg);
 		info->mark = 0;
 		info->mask = ~mask;
 		break;
 
 	case '|': /* --or-mark */
-		param_act(P_ONE_ACTION, "MARK", *flags & F_MARK);
-		param_act(P_NO_INVERT, "MARK", "--or-mark", invert);
-		if (!strtonum(optarg, NULL, &value, 0, ~0U))
-			param_act(P_BAD_VALUE, "MARK", "--or-mark", optarg);
+		xtables_param_act(XTF_ONE_ACTION, "MARK", *flags & F_MARK);
+		xtables_param_act(XTF_NO_INVERT, "MARK", "--or-mark", invert);
+		if (!xtables_strtoui(optarg, NULL, &value, 0, UINT32_MAX))
+			xtables_param_act(XTF_BAD_VALUE, "MARK", "--or-mark", optarg);
 		info->mark = value;
 		info->mask = value;
 		break;
 
 	case '^': /* --xor-mark */
-		param_act(P_ONE_ACTION, "MARK", *flags & F_MARK);
-		param_act(P_NO_INVERT, "MARK", "--xor-mark", invert);
-		if (!strtonum(optarg, NULL, &value, 0, ~0U))
-			param_act(P_BAD_VALUE, "MARK", "--xor-mark", optarg);
+		xtables_param_act(XTF_ONE_ACTION, "MARK", *flags & F_MARK);
+		xtables_param_act(XTF_NO_INVERT, "MARK", "--xor-mark", invert);
+		if (!xtables_strtoui(optarg, NULL, &value, 0, UINT32_MAX))
+			xtables_param_act(XTF_BAD_VALUE, "MARK", "--xor-mark", optarg);
 		info->mark = value;
 		info->mask = 0;
 		break;
@@ -189,7 +188,7 @@ static int mark_tg_parse(int c, char **argv, int invert, unsigned int *flags,
 static void mark_tg_check(unsigned int flags)
 {
 	if (flags == 0)
-		exit_error(PARAMETER_PROBLEM, "MARK: One of the --set-xmark, "
+		xtables_error(PARAMETER_PROBLEM, "MARK: One of the --set-xmark, "
 		           "--{and,or,xor,set}-mark options is required");
 }
 
@@ -199,7 +198,6 @@ print_mark(unsigned long mark)
 	printf("0x%lx ", mark);
 }
 
-/* Prints out the targinfo. */
 static void MARK_print_v0(const void *ip,
                           const struct xt_entry_target *target, int numeric)
 {
@@ -209,7 +207,6 @@ static void MARK_print_v0(const void *ip,
 	print_mark(markinfo->mark);
 }
 
-/* Saves the union ipt_targinfo in parsable form to stdout. */
 static void MARK_save_v0(const void *ip, const struct xt_entry_target *target)
 {
 	const struct xt_mark_target_info *markinfo =
@@ -219,7 +216,6 @@ static void MARK_save_v0(const void *ip, const struct xt_entry_target *target)
 	print_mark(markinfo->mark);
 }
 
-/* Prints out the targinfo. */
 static void MARK_print_v1(const void *ip, const struct xt_entry_target *target,
                           int numeric)
 {
@@ -255,7 +251,6 @@ static void mark_tg_print(const void *ip, const struct xt_entry_target *target,
 		printf("MARK xset 0x%x/0x%x ", info->mark, info->mask);
 }
 
-/* Saves the union ipt_targinfo in parsable form to stdout. */
 static void MARK_save_v1(const void *ip, const struct xt_entry_target *target)
 {
 	const struct xt_mark_target_info_v1 *markinfo =
@@ -283,7 +278,7 @@ static void mark_tg_save(const void *ip, const struct xt_entry_target *target)
 }
 
 static struct xtables_target mark_target_v0 = {
-	.family		= AF_INET,
+	.family		= NFPROTO_IPV4,
 	.name		= "MARK",
 	.version	= XTABLES_VERSION,
 	.revision	= 0,
@@ -298,7 +293,7 @@ static struct xtables_target mark_target_v0 = {
 };
 
 static struct xtables_target mark_target_v1 = {
-	.family		= AF_INET,
+	.family		= NFPROTO_IPV4,
 	.name		= "MARK",
 	.version	= XTABLES_VERSION,
 	.revision	= 1,
@@ -313,7 +308,7 @@ static struct xtables_target mark_target_v1 = {
 };
 
 static struct xtables_target mark_target6_v0 = {
-	.family		= AF_INET6,
+	.family		= NFPROTO_IPV6,
 	.name		= "MARK",
 	.version	= XTABLES_VERSION,
 	.revision	= 0,
